@@ -1,12 +1,14 @@
 #' \code{standby} package
-#' 
+#'
 #' Loading screens for Shiny.
-#' 
-#' See the README on 
+#'
+#' See the README on
 #' \href{https://github.com/rsquaredacademy/standby}{GitHub}
-#' 
+#'
 #' @import shiny htmltools grDevices
 #' @keywords internal
 #' @docType package
 #' @name standby
-NULL
\ No newline at end of file
+#' @aliases standby-package
+"_PACKAGE"
+NULL
